@@ -3,39 +3,36 @@
 #' @importFrom stats na.omit
 NULL
 
-huxtable_cell_attrs <- c('align', 'valign', 'rowspan', 'colspan', 'background_color', 'text_color',
-  'top_border', 'left_border', 'right_border', 'bottom_border',
-  'top_border_color', 'left_border_color', 'right_border_color', 'bottom_border_color',
-  'top_border_style', 'left_border_style', 'right_border_style', 'bottom_border_style',
-  'top_padding', 'left_padding', 'right_padding', 'bottom_padding', 'wrap',
-  'escape_contents', 'na_string', 'bold', 'italic', 'font_size', 'rotation', 'number_format',
-  'font', 'pad_decimal')
-huxtable_col_attrs <- c('col_width')
-huxtable_row_attrs <- c('row_height')
-huxtable_table_attrs <- c('width', 'height', 'position', 'caption', 'caption_pos',
-  'tabular_environment', 'label', 'latex_float')
 
-make_namespace_S3_entries <- function (accessors) {
-    entries <- lapply(accessors, function (getter) {
-    setter <- paste0('"', getter, '<-"')
-    paste0('S3method(', c(getter, setter), ', huxtable)')
-  })
+huxtable_cell_attrs <- c("align", "valign", "rowspan", "colspan", "background_color", "text_color",
+  "top_border", "left_border", "right_border", "bottom_border",
+  "top_border_color", "left_border_color", "right_border_color", "bottom_border_color",
+  "top_border_style", "left_border_style", "right_border_style", "bottom_border_style",
+  "top_padding", "left_padding", "right_padding", "bottom_padding", "wrap",
+  "escape_contents", "na_string", "bold", "italic", "font_size", "rotation", "number_format",
+  "font", "pad_decimal")
+huxtable_col_attrs <- c("col_width")
+huxtable_row_attrs <- c("row_height")
+huxtable_table_attrs <- c("width", "height", "position", "caption", "caption_pos",
+  "tabular_environment", "label", "latex_float")
 
-  unlist(entries)
-}
 
 #' @evalNamespace make_namespace_S3_entries(huxtable_cell_attrs)
 #' @evalNamespace make_namespace_S3_entries(huxtable_col_attrs)
 #' @evalNamespace make_namespace_S3_entries(huxtable_row_attrs)
 #' @evalNamespace make_namespace_S3_entries(huxtable_table_attrs)
+#' @evalNamespace make_exports(huxtable_col_attrs)
+#' @evalNamespace make_exports(huxtable_row_attrs)
+#' @evalNamespace make_exports(huxtable_table_attrs)
+#' @evalNamespace make_exports(huxtable_cell_attrs, with_map = TRUE)
 NULL
 
 huxtable_env <- new.env()
 huxtable_env$huxtable_default_attrs <- list(
         rowspan             = 1,
         colspan             = 1,
-        align               = 'left',
-        valign              = 'top',
+        align               = "left",
+        valign              = "top",
         width               = 0.5,
         height              = NA,
         col_width           = NA,
@@ -50,33 +47,33 @@ huxtable_env$huxtable_default_attrs <- list(
         right_border_color  = NA,
         top_border_color    = NA,
         bottom_border_color = NA,
-        left_border_style   = 'solid',
-        right_border_style  = 'solid',
-        top_border_style    = 'solid',
-        bottom_border_style = 'solid',
+        left_border_style   = "solid",
+        right_border_style  = "solid",
+        top_border_style    = "solid",
+        bottom_border_style = "solid",
         left_padding        = 4,
         right_padding       = 4,
         top_padding         = 4,
         bottom_padding      = 4,
         wrap                = FALSE,
         caption             = NA,
-        caption_pos         = 'top',
-        position            = 'center',
-        tabular_environment = 'tabularx',
+        caption_pos         = "top",
+        position            = "center",
+        tabular_environment = "tabularx",
         label               = NA,
-        latex_float         = 'h',
+        latex_float         = "h",
         escape_contents     = TRUE,
-        na_string           = '',
+        na_string           = "",
         bold                = FALSE,
         italic              = FALSE,
         font_size           = NA,
         rotation            = 0,
-        number_format       = list('%.3g'),
+        number_format       = list("%.3g"),
         pad_decimal         = NA,
         font                = NA
       )
 
-make_getter_setters <- function(attr_name, attr_type = c('cell', 'row', 'col', 'table'), check_fun = NULL,
+make_getter_setters <- function(attr_name, attr_type = c("cell", "row", "col", "table"), check_fun = NULL,
   check_values = NULL, extra_code = NULL) {
   attr_type <- match.arg(attr_type)
   funs <- list()
@@ -84,11 +81,11 @@ make_getter_setters <- function(attr_name, attr_type = c('cell', 'row', 'col', '
   funs[[attr_name]] <- eval(bquote(
     function(ht) UseMethod(.(attr_name))
   ))
-  funs[[paste0(attr_name, '.huxtable')]] <- eval(bquote(
+  funs[[paste0(attr_name, ".huxtable")]] <- eval(bquote(
     function(ht) attr(ht, .(attr_name))
   ))
 
-  setter <- paste0(attr_name, '<-')
+  setter <- paste0(attr_name, "<-")
   funs[[setter]] <- eval(bquote(
     function(ht, value) UseMethod(.(setter))
   ))
@@ -101,7 +98,7 @@ make_getter_setters <- function(attr_name, attr_type = c('cell', 'row', 'col', '
     assert_that(all(na.omit(value) %in% .(check_values)))
   )
   extra_code <- if (! missing(extra_code)) substitute(extra_code)
-  funs[[paste0(setter, '.huxtable')]] <- eval(bquote(
+  funs[[paste0(setter, ".huxtable")]] <- eval(bquote(
     function(ht, value) {
       if (! all(is.na(value))) .(check_fun)
       .(check_dims)
@@ -114,8 +111,10 @@ make_getter_setters <- function(attr_name, attr_type = c('cell', 'row', 'col', '
     }
   ))
 
-  alt_setter <- paste0('set_', attr_name)
+  alt_setter  <- sprintf("set_%s", attr_name)
+  mapping_fun <- sprintf("map_%s", attr_name)
   attr_symbol <- as.symbol(attr_name)
+
   funs[[alt_setter]] <- switch(attr_type,
         cell = eval(bquote(
           function(ht, row, col, value, byrow = FALSE) {
@@ -124,8 +123,10 @@ make_getter_setters <- function(attr_name, attr_type = c('cell', 'row', 'col', '
             if (! missing(byrow)) nargs <- nargs - 1
             if (nargs == 3) {
               if (missing(value)) value <- col
-              if (! is.matrix(row)) stop('No columns specified, but `row` argument did not evaluate to a matrix')
-              if (byrow) stop('`byrow = TRUE` makes no sense if `row` is a matrix')
+              if (! is.matrix(row)) stop("No columns specified, but `row` argument did not evaluate to a matrix")
+              if (byrow) stop("`byrow = TRUE` makes no sense if `row` is a matrix")
+              # .Deprecated(msg = c("The 3 argument form of `set_xxx` functions is deprecated.\n",
+              #       "Use `map_xxx` instead.\n"), package = "huxtable")
               .(attr_symbol)(ht)[row] <- value
             } else {
               if (nargs == 2) {
@@ -175,7 +176,30 @@ make_getter_setters <- function(attr_name, attr_type = c('cell', 'row', 'col', '
           }
         ))
   ) # end switch
-  hux_ns <- getNamespace('huxtable')
+
+  funs[[mapping_fun]] <- eval(bquote(
+    function (ht, row, col, fn) {
+      assert_that(is_huxtable(ht))
+      nargs <- nargs()
+
+      if (nargs() == 2) {
+        if (missing(fn)) fn <- row
+        row <- seq_len(nrow(ht))
+        col <- seq_len(ncol(ht))
+      }
+      rc <- list()
+      rc$row <- get_rc_spec(ht, row, 1)
+      rc$col <- get_rc_spec(ht, col, 2)
+
+      current <- .(as.name(attr_name))(ht)[rc$row, rc$col, drop = FALSE]
+      if (is_huxtable(current)) current <- as.matrix(current)
+      .(as.name(attr_name))(ht)[rc$row, rc$col] <- fn(ht, rc$row, rc$col, current)
+
+      ht
+    }
+  ))
+
+  hux_ns <- getNamespace("huxtable")
   lapply(names(funs), function (x) {
     environment(funs[[x]]) <- hux_ns
     assign(x, funs[[x]], envir = hux_ns)
@@ -188,39 +212,37 @@ make_getter_setters <- function(attr_name, attr_type = c('cell', 'row', 'col', '
 #' @template getset-cell
 #' @templateVar attr_name valign
 #' @templateVar attr_desc Vertical alignment
-#' @templateVar value_param_desc A character vector or matrix which may be 'top', 'middle', 'bottom' or `NA`.
+#' @templateVar value_param_desc A character vector or matrix which may be "top", "middle", "bottom" or `NA`.
 #' @template getset-example
-#' @templateVar attr_val 'bottom'
+#' @templateVar attr_val "bottom"
 #' @template getset-rowspec-example
-#' @templateVar attr_val2 'bottom'
+#' @templateVar attr_val2 "bottom"
 #' @details
 #' Vertical alignment may not work for short text in LaTeX. Defining row heights with [row_height()]
 #' may help.
-#' @export valign valign<- set_valign
 NULL
-make_getter_setters('valign', 'cell', check_fun = is.character, check_values = c('top', 'middle', 'bottom'))
+make_getter_setters("valign", "cell", check_fun = is.character, check_values = c("top", "middle", "bottom"))
 
 
 check_align_value <- function (x) {
   x <- na.omit(x)
-  is.character(x) && all(x %in% c('left', 'centre', 'center', 'right') | ncharw(x) == 1)
+  is.character(x) && all(x %in% c("left", "centre", "center", "right") | ncharw(x) == 1)
 }
 
 
 #' @template getset-cell
 #' @templateVar attr_name align
 #' @templateVar attr_desc Alignment
-#' @templateVar value_param_desc A character vector or matrix which may be 'left', 'center', 'right' , `NA` or a single character.
+#' @templateVar value_param_desc A character vector or matrix which may be "left", "center", "right" , `NA` or a single character.
 #' @template getset-example
-#' @templateVar attr_val 'right'
+#' @templateVar attr_val "right"
 #' @template getset-visible-rowspec-example
-#' @templateVar attr_val2 'left'
+#' @templateVar attr_val2 "left"
 #' @details This sets the horizontal alignment of the cell. If `value` is a single character (e.g.
 #' a decimal point), then the cell is aligned on this character.
-#' @export align align<- set_align
 NULL
-make_getter_setters('align', 'cell', check_fun = check_align_value,
-      extra_code = value[value == 'centre'] <- 'center')
+make_getter_setters("align", "cell", check_fun = check_align_value,
+      extra_code = value[value == "centre"] <- "center")
 
 
 #' @template getset-rowcol
@@ -235,9 +257,8 @@ make_getter_setters('align', 'cell', check_fun = check_align_value,
 #' @family row/column heights
 #' @template getset-example
 #' @templateVar attr_val c(.2, .8)
-#' @export col_width col_width<- set_col_width
 NULL
-make_getter_setters('col_width', 'col')
+make_getter_setters("col_width", "col")
 
 
 #' @template getset-rowcol
@@ -250,10 +271,9 @@ make_getter_setters('col_width', 'col')
 #' If character, `value` must contain valid CSS or LaTeX lengths. If numeric, in HTML, values are scaled to 1 and treated as proportions of the table height. In LaTeX, they are
 #' treated as proportions of the text height (`\\textheight`).
 #' @template getset-example
-#' @templateVar attr_val c(.2, .1, .1)
-#' @export row_height row_height<- set_row_height
+#' @templateVar attr_val c(.2, .1, .1, .1)
 NULL
-make_getter_setters('row_height', 'row')
+make_getter_setters("row_height", "row")
 
 
 #' @template getset-cell
@@ -268,42 +288,38 @@ make_getter_setters('row_height', 'row')
 #' @noMd
 #' @templateVar subscript [1, 1]
 #' @templateVar attr_val 2
-#' @templateVar extra ht <- set_all_borders(ht, 1) ## ht
-#' @export rowspan rowspan<- set_rowspan
+#' @templateVar extra jams <- set_all_borders(jams, 1) ## jams
 NULL
-make_getter_setters('rowspan', 'cell', check_fun = is.numeric, extra_code = {
-      if (any(na.omit( row(ht) + value - 1 > nrow(ht) ))) stop('rowspan would extend beyond bottom of table')
-      check_span_shadows(ht, 'row', value)
+make_getter_setters("rowspan", "cell", check_fun = is.numeric, extra_code = {
+      if (any(na.omit( row(ht) + value - 1 > nrow(ht) ))) stop("rowspan would extend beyond bottom of table")
+      check_span_shadows(ht, "row", value)
     }
 )
 
 
 #' @name colspan
 #' @rdname rowspan
-#' @usage
-#' colspan(ht)
-#' colspan(ht) <- value
-#' set_colspan(ht, row, col, value, byrow = FALSE)
-#' @aliases colspan<- set_colspan
-#' @export colspan colspan<- set_colspan
+#' @templateVar attr_name colspan
+#' @template cell-property-usage
+#' @aliases colspan<- set_colspan map_colspan
 NULL
-make_getter_setters('colspan', 'cell', check_fun = is.numeric, extra_code = {
+make_getter_setters("colspan", "cell", check_fun = is.numeric, extra_code = {
       if (any(na.omit( col(ht) + value - 1 > ncol(ht) ))) stop(
-            'colspan would extend beyond right edge of table')
-      check_span_shadows(ht, 'col', value)
+            "colspan would extend beyond right edge of table")
+      check_span_shadows(ht, "col", value)
     }
 )
 
 
 check_span_shadows <- function (ht, rc, value) {
   value[is.na(value)] <- 1L
-  dcells <- if (rc == 'row') display_cells(ht, new_rowspan = value) else display_cells(ht, new_colspan = value)
-  candidates <- as.matrix(dcells[dcells$shadowed, c('row', 'col')])
+  dcells <- if (rc == "row") display_cells(ht, new_rowspan = value) else display_cells(ht, new_colspan = value)
+  candidates <- as.matrix(dcells[dcells$shadowed, c("row", "col")])
   problems <- value[candidates] > 1 # span of cells which would be shadowed;
   if (any(problems)) {
     candidates <- candidates[problems, , drop = FALSE]
-    candidates <- paste(apply(candidates, 1, paste, collapse = ','), collapse = '; ')
-    stop('New rowspan/colspan would cut up existing multirow/multicol cells at ', candidates)
+    candidates <- paste(apply(candidates, 1, paste, collapse = ","), collapse = "; ")
+    stop("New rowspan/colspan would cut up existing multirow/multicol cells at ", candidates)
   }
 }
 
@@ -315,11 +331,10 @@ check_span_shadows <- function (ht, rc, value) {
 #' @template getset-example
 #' @templateVar attr_val grey(.95)
 #' @template getset-visible-rowspec-example
-#' @templateVar attr_val2 'yellow'
+#' @templateVar attr_val2 "yellow"
 #' @family formatting functions
-#' @export background_color background_color<- set_background_color
 NULL
-make_getter_setters('background_color', 'cell')
+make_getter_setters("background_color", "cell")
 
 
 #' @template getset-cell
@@ -329,13 +344,12 @@ make_getter_setters('background_color', 'cell')
 #' @details
 #' Colors can be in any format understood by R, e.g. `"red"`, `"#FF0000"` or `rgb(1, 0, 0)`.
 #' @template getset-example
-#' @templateVar attr_val 'blue'
+#' @templateVar attr_val "blue"
 #' @template getset-visible-rowspec-example
-#' @templateVar attr_val2 'red'
+#' @templateVar attr_val2 "red"
 #' @family formatting functions
-#' @export text_color text_color<- set_text_color
 NULL
-make_getter_setters('text_color', 'cell')
+make_getter_setters("text_color", "cell")
 
 
 #' @template getset-cell
@@ -350,44 +364,35 @@ make_getter_setters('text_color', 'cell')
 #' @seealso [set_all_borders()]
 #' @template getset-example
 #' @templateVar attr_val 1
-#' @templateVar extra print_screen(ht)
+#' @templateVar extra jams
+#' @templateVar attr_val2 0
 #' @template getset-visible-rowspec-example
-#' @templateVar attr_val2 2
 #' @template border-warning
-#' @export left_border left_border<- set_left_border
+#' @template cell-property-usage
 NULL
-for (val in paste0(c('left', 'right', 'top', 'bottom'), '_border')) make_getter_setters(val, 'cell',
+for (val in paste0(c("left", "right", "top", "bottom"), "_border")) make_getter_setters(val, "cell",
       check_fun = is.numeric)
 
 
 #' @name right_border
 #' @rdname left_border
 #' @return Similarly for the other functions.
-#' @usage
-#' right_border(ht)
-#' right_border(ht) <- value
-#' set_right_border(ht, row, col, value, byrow = FALSE)
-#' @export right_border right_border<- set_right_border
+#' @templateVar attr_name right_border
+#' @template cell-property-usage
 NULL
 
 
 #' @name top_border
 #' @rdname left_border
-#' @usage
-#' top_border(ht)
-#' top_border(ht) <- value
-#' set_top_border(ht, row, col, value, byrow = FALSE)
-#' @export top_border top_border<- set_top_border
+#' @templateVar attr_name top_border
+#' @template cell-property-usage
 NULL
 
 
 #' @name bottom_border
 #' @rdname left_border
-#' @usage
-#' bottom_border(ht)
-#' bottom_border(ht) <- value
-#' set_bottom_border(ht, row, col, value, byrow = FALSE)
-#' @export bottom_border bottom_border<- set_bottom_border
+#' @templateVar attr_name bottom_border
+#' @template cell-property-usage
 NULL
 
 
@@ -396,65 +401,57 @@ NULL
 #' @templateVar attr_desc Border colors
 #' @templateVar value_param_desc A vector or matrix of colors.
 #' @templateVar morealiases right_border_color top_border_color bottom_border_color
-#' @templateVar attr_val 'red'
+#' @templateVar attr_val "red"
 #' @details
 #' Huxtable collapses borders and border colors. Right borders take priority over left borders, and
 #' top borders take priority over bottom borders.
 #'
 #' @seealso [set_all_border_colors()]
-#' @templateVar attr_val2 'blue'
-#' @export left_border_color left_border_color<- set_left_border_color
+#' @templateVar attr_val2 "blue"
 #' @examples
 #' ht <- huxtable(a = 1:3, b = 3:1)
 #' ht <- set_all_borders(ht, 1)
-#' set_left_border_color(ht, 'red')
-#' set_left_border_color(ht, 1:2, 1, 'red')
-#' set_left_border_color(ht, 1:2, 1:2, c('red', 'blue'), byrow = TRUE)
-#' set_left_border_color(ht, where(ht == 1), 'red')
+#' set_left_border_color(ht, "red")
+#' set_left_border_color(ht,
+#'       1:2, 1, "red")
+#'
 #' @template border-warning
+#' @template cell-property-usage
 #'
 NULL
-for (val in paste0(c('left', 'right', 'top', 'bottom'), '_border_color')) make_getter_setters(val,
-  'cell')
+for (val in paste0(c("left", "right", "top", "bottom"), "_border_color")) make_getter_setters(val,
+  "cell")
 
 
 #' @name right_border_color
 #' @rdname left_border_color
 #' @return Similarly for the other functions.
-#' @usage
-#' right_border_color(ht)
-#' right_border_color(ht) <- value
-#' set_right_border_color(ht, row, col, value, byrow = FALSE)
-#' @export right_border_color right_border_color<- set_right_border_color
+#' @templateVar attr_name right_border_color
+#' @template cell-property-usage
 NULL
 
 
 #' @name top_border_color
 #' @rdname left_border_color
-#' @usage
-#' top_border_color(ht)
-#' top_border_color(ht) <- value
-#' set_top_border_color(ht, row, col, value, byrow = FALSE)
-#' @export top_border_color top_border_color<- set_top_border_color
+#' @templateVar attr_name top_border_color
+#' @template cell-property-usage
 NULL
 
 
 #' @name bottom_border_color
 #' @rdname left_border_color
-#' @usage
-#' bottom_border_color(ht)
-#' bottom_border_color(ht) <- value
-#' set_bottom_border_color(ht, row, col, value, byrow = FALSE)
-#' @export bottom_border_color bottom_border_color<- set_bottom_border_color
+#' @templateVar attr_name bottom_border_color
+#' @template cell-property-usage
 NULL
 
 
-#' @template getset-cell
 #' @templateVar attr_name left_border_style
 #' @templateVar attr_desc Border styles
 #' @templateVar value_param_desc A character vector or matrix of styles, which may be "solid", "double", "dashed" or "dotted".
 #' @templateVar morealiases right_border_style top_border_style bottom_border_style
-#' @templateVar attr_val 'solid'
+#' @templateVar attr_val "solid"
+#' @template getset-cell
+#' @template cell-property-usage
 #' @details
 #' Huxtable collapses borders and border colors. Right borders take priority over left borders, and
 #' top borders take priority over bottom borders.
@@ -466,50 +463,40 @@ NULL
 #' * In HTML, you will need to set a width of at least 3 to get a double border.
 #' * Only "solid" and "double" styles are currently implemented in LaTeX.
 #'
-#' @templateVar attr_val2 'double'
-#' @export left_border_style left_border_style<- set_left_border_style
+#' @templateVar attr_val2 "double"
 #' @examples
 #' ht <- huxtable(a = 1:3, b = 3:1)
 #' ht <- set_all_borders(ht, 1)
-#' set_left_border_style(ht, 'double')
-#' set_left_border_style(ht, 1:2, 1, 'double')
-#' set_left_border_style(ht, 1:2, 1:2, c('solid', 'double'), byrow = TRUE)
-#' set_left_border_style(ht, where(ht == 1), 'double')
-#' @template border-warning
+#' set_left_border_style(ht, "double")
+#' set_left_border_style(ht, 1:2, 1,
+#'       "double")
 #'
+#' @template border-warning
+#' @template cell-property-usage
 NULL
-for (val in paste0(c('left', 'right', 'top', 'bottom'), '_border_style')) make_getter_setters(val,
-      'cell', check_values = c('solid', 'double', 'dashed', 'dotted'))
+for (val in paste0(c("left", "right", "top", "bottom"), "_border_style")) make_getter_setters(val,
+      "cell", check_values = c("solid", "double", "dashed", "dotted"))
 
 
 #' @name right_border_style
 #' @rdname left_border_style
 #' @return Similarly for the other functions.
-#' @usage
-#' right_border_style(ht)
-#' right_border_style(ht) <- value
-#' set_right_border_style(ht, row, col, value, byrow = FALSE)
-#' @export right_border_style right_border_style<- set_right_border_style
+#' @templateVar attr_name right_border_style
+#' @template cell-property-usage
 NULL
 
 
 #' @name top_border_style
 #' @rdname left_border_style
-#' @usage
-#' top_border_style(ht)
-#' top_border_style(ht) <- value
-#' set_top_border_style(ht, row, col, value, byrow = FALSE)
-#' @export top_border_style top_border_style<- set_top_border_style
+#' @templateVar attr_name top_border_style
+#' @template cell-property-usage
 NULL
 
 
 #' @name bottom_border_style
 #' @rdname left_border_style
-#' @usage
-#' bottom_border_style(ht)
-#' bottom_border_style(ht) <- value
-#' set_bottom_border_style(ht, row, col, value, byrow = FALSE)
-#' @export bottom_border_style bottom_border_style<- set_bottom_border_style
+#' @templateVar attr_name bottom_border_style
+#' @template cell-property-usage
 NULL
 
 
@@ -524,39 +511,30 @@ NULL
 #' @templateVar attr_val 20
 #' @template getset-rowspec-example
 #' @templateVar attr_val2 10
-#' @export left_padding left_padding<- set_left_padding
+#' @template cell-property-usage
 NULL
-for (val in paste0(c('left', 'right', 'top', 'bottom'), '_padding')) make_getter_setters(val, 'cell')
+for (val in paste0(c("left", "right", "top", "bottom"), "_padding")) make_getter_setters(val, "cell")
 
 
 #' @name right_padding
 #' @rdname left_padding
 #' @return Similarly for the other functions.
-#' @usage
-#' right_padding(ht)
-#' right_padding(ht) <- value
-#' set_right_padding(ht, row, col, value, byrow = FALSE)
-#' @export right_padding right_padding<- set_right_padding
-NULL
-
-
-#' @name bottom_padding
-#' @rdname left_padding
-#' @usage
-#' bottom_padding(ht)
-#' bottom_padding(ht) <- value
-#' set_bottom_padding(ht, row, col, value, byrow = FALSE)
-#' @export bottom_padding bottom_padding<- set_bottom_padding
+#' @templateVar attr_name right_padding
+#' @template cell-property-usage
 NULL
 
 
 #' @name top_padding
 #' @rdname left_padding
-#' @usage
-#' top_padding(ht)
-#' top_padding(ht) <- value
-#' set_top_padding(ht, row, col, value, byrow = FALSE)
-#' @export top_padding top_padding<- set_top_padding
+#' @templateVar attr_name top_padding
+#' @template cell-property-usage
+NULL
+
+
+#' @name bottom_padding
+#' @rdname left_padding
+#' @templateVar attr_name bottom_padding
+#' @template cell-property-usage
 NULL
 
 
@@ -564,18 +542,24 @@ NULL
 #' @templateVar attr_name wrap
 #' @templateVar attr_desc Text wrapping
 #' @templateVar value_param_desc
-#' A logical vector or matrix. If `TRUE`, long cell contents will be wrapped into multiple lines. Set to `NA` for the default.
+#' A logical vector or matrix. If `TRUE`, long cell contents will be wrapped into multiple lines.
+#' Set to `NA` for the default.
 #' @examples
-#' ht <- huxtable(a = rep('Some long text', 2))
-#' wrap(ht)[1,] <- TRUE
-#' print_html(ht)
+#' ht <- huxtable(paste(
+#'       rep("Some long text.", 20),
+#'       collapse = " "))
+#' width(ht) <- 0.2
+#' wrap(ht) <- TRUE
+#' \dontrun{
+#'   quick_html(ht)
+#' }
+#'
 #' @template getset-rowspec-example
 #' @templateVar attr_val TRUE
 #' @templateVar attr_val2 FALSE
 #'
-#' @export wrap wrap<- set_wrap
 NULL
-make_getter_setters('wrap', 'cell', check_fun = is.logical)
+make_getter_setters("wrap", "cell", check_fun = is.logical)
 
 
 #' @template getset-cell
@@ -584,14 +568,21 @@ make_getter_setters('wrap', 'cell', check_fun = is.logical)
 #' @templateVar value_param_desc
 #' A logical vector or matrix. If `TRUE`, cell contents will be HTML or LaTeX escaped.
 #' @examples
-#' ht <- huxtable(Exponent = 2:4, Example = paste0('$x^', 2:4, '$'))
+#' ht <- huxtable(
+#'         Exponent = 2:4,
+#'         Example  = paste0("$x^", 2:4, "$"),
+#'         add_colnames = TRUE
+#'       )
 #' escape_contents(ht)[,2] <- FALSE
+#' \dontrun{
+#'   quick_pdf(ht)
+#' }
+#'
 #' @template getset-rowspec-example
 #' @templateVar attr_val TRUE
 #' @templateVar attr_val2 FALSE
-#' @export escape_contents escape_contents<- set_escape_contents
 NULL
-make_getter_setters('escape_contents', 'cell', check_fun = is.logical)
+make_getter_setters("escape_contents", "cell", check_fun = is.logical)
 
 
 #' @template getset-cell
@@ -600,45 +591,40 @@ make_getter_setters('escape_contents', 'cell', check_fun = is.logical)
 #' @templateVar value_param_desc
 #' A character string. This will be used to replace NA values in the display.
 #' @template getset-example
-#' @templateVar attr_val '--'
+#' @templateVar attr_val "--"
 #' @noMd
-#' @templateVar extra ht[2,2] <- NA ## print_screen(ht)
+#' @templateVar extra jams[2,2] <- NA ## jams
 #' @template getset-rowspec-example
-#' @templateVar attr_val2 ''
+#' @templateVar attr_val2 ""
 #' @family formatting functions
-#' @export na_string na_string<- set_na_string
 NULL
-make_getter_setters('na_string', 'cell', check_fun = is.character)
+make_getter_setters("na_string", "cell", check_fun = is.character)
 
 
 #' @template getset-cell
 #' @templateVar attr_name bold
 #' @templateVar attr_desc Cell text style
 #' @templateVar value_param_desc
-#' A logical vector or matrix
+#' A logical vector or matrix. `TRUE` for bold/italic.
 #' @templateVar morealiases italic
 #' @template getset-example
 #' @templateVar attr_val TRUE
-#' @templateVar extra print_screen(ht)
 #' @template getset-visible-rowspec-example
 #' @templateVar attr_val2 FALSE
 #' @family formatting functions
-#' @export bold bold<- set_bold
+#' @template cell-property-usage
 NULL
-make_getter_setters('bold', 'cell', check_fun = is.logical)
+make_getter_setters("bold", "cell", check_fun = is.logical)
 
 
 #' @name italic
 #' @rdname bold
-#' @usage
-#' italic(ht)
-#' italic(ht) <- value
-#' set_italic(ht, row, col, value, byrow = FALSE)
+#' @templateVar attr_name italic
+#' @template cell-property-usage
 #' @return
 #' Similarly for \code{italic} and friends.
-#' @export italic italic<- set_italic
 NULL
-make_getter_setters('italic', 'cell', check_fun = is.logical)
+make_getter_setters("italic", "cell", check_fun = is.logical)
 
 
 #' @template getset-cell
@@ -651,9 +637,8 @@ make_getter_setters('italic', 'cell', check_fun = is.logical)
 #' @template getset-rowspec-example
 #' @templateVar attr_val2 12
 #' @family formatting functions
-#' @export font_size font_size<- set_font_size
 NULL
-make_getter_setters('font_size', 'cell', check_fun = is.numeric)
+make_getter_setters("font_size", "cell", check_fun = is.numeric)
 
 
 #' @template getset-cell
@@ -668,16 +653,15 @@ make_getter_setters('font_size', 'cell', check_fun = is.numeric)
 #' @details
 #' You will probably need to set [col_width()] and [row_height()] explicitly
 #' to achieve a nice result, in both HTML and LaTeX.
-#' @export rotation rotation<- set_rotation
 NULL
-make_getter_setters('rotation', 'cell', check_fun = is.numeric)
+make_getter_setters("rotation", "cell", check_fun = is.numeric, extra_code = {value <- value %% 360})
+
 
 #' @template getset-cell
 #' @templateVar attr_name number_format
 #' @templateVar attr_desc Number format
-#' @templateVar value_param_desc (Not shown - overwritten by the below.)
-#' @param value A character or integer vector, or a list containing a function, or \code{NA}. Note
-#'   that setting to \code{NA} does not reset to the default.
+#' @templateVar value_param_desc A character or integer vector, or a list containing a function, or \code{NA}.
+#' @templateVar NA_does_not_reset TRUE
 #' @details
 #' Number formatting is applied to any parts of cells that look like numbers (defined as an optional minus sign,
 #' followed by
@@ -707,56 +691,109 @@ make_getter_setters('rotation', 'cell', check_fun = is.numeric)
 #'
 #' @examples
 #' ht <- huxtable(
-#'   number_format = c("Default", "NA", "2", "\"%5.2f\"", "Pretty", "Sign"),
-#'   a = rep(1000, 6),
-#'   b = rep(1000.005, 6),
-#'   c = rep(0.0001, 6),
-#'   d = rep(-1, 6),
-#'   e = rep("3.2 (s.e. 1.4)", 6),
-#'   add_colnames = TRUE
-#' )
+#'         number_format = c(
+#'           "Default",
+#'           "NA",
+#'           "2",
+#'           "\"%5.2f\"",
+#'           "Pretty",
+#'           "Sign"
+#'         ),
+#'         a = rep(1000, 6),
+#'         b = rep(1000.005, 6),
+#'         c = rep(0.0001, 6),
+#'         d = rep(-1, 6),
+#'         e = rep("3.2 (s.e. 1.4)", 6),
+#'         add_colnames = TRUE
+#'       )
+#'
 #' number_format(ht)[3, -1] <- NA
 #' number_format(ht)[4, -1] <- 2
-#' number_format(ht)[5, -1] <- '%5.2f'
-#' number_format(ht)[6, -1] <- list(function(x) prettyNum(x, big.mark = ',', scientific = FALSE))
-#' number_format(ht)[7, -1] <- list(function(x) if(x>0) '+' else '-')
+#' number_format(ht)[5, -1] <- "%5.2f"
+#'
+#' number_format(ht)[6, -1] <- list(
+#'         function(x)
+#'           prettyNum(x, big.mark = ",",
+#'                 scientific = FALSE)
+#'       )
+#'
+#' number_format(ht)[7, -1] <- list(
+#'         function(x) if (x > 0) "+" else "-"
+#'       )
+#'
 #' right_border(ht) <- 1
 #' bottom_border(ht)[1, ] <- 1
+#'
 #' ht
 #'
 #' ht_bands <- huxtable("10000 Maniacs", autoformat = FALSE)
 #' # probably not what you want:
 #' ht_bands
-#' number_format(ht_bands) <- NA
-#' ht_bands
+#' # fixed:
+#' set_number_format(ht_bands, NA)
 #' # alternatively:
 #' huxtable("10000 Maniacs", autoformat = TRUE)
+#'
 #' @template getset-visible-rowspec-example
 #' @templateVar attr_val 2
 #' @templateVar attr_val2 3
-#' @export number_format number_format<- set_number_format
 NULL
-make_getter_setters('number_format', 'cell')
+make_getter_setters("number_format", "cell")
 
 
 # override the default
 `number_format<-.huxtable` <- function(ht, value) {
   stopifnot(all(sapply(value, function (x) is.numeric(x) || is.character(x) || is.function(x) || is.na(x) )))
-  attr(ht, 'number_format')[] <- value
+  attr(ht, "number_format")[] <- value
   ht
 }
 
 
-#' @aliases pad_decimal<- set_pad_decimal
+#' Set cell contents
+#'
+#' `set_contents()` is a convenience function to change the cell contents of a huxtable within
+#' a dplyr chain. `set_contents(ht, x, y, foo)` just calls `ht[x, y] <- foo` and returns `ht`.
+#'
+#' @template cell-property-usage
+#' @templateVar attr_name contents
+#'
+#' @param ht A huxtable.
+#' @param value Cell contents.
+#' @param row A row specifier. See [rowspecs] for details.
+#' @param col An optional column specifier.
+#' @param fn A mapping function. See [mapping-functions] for details.
+#' @param byrow Deprecated. Use [by_cols()] instead.
+#'
+#' @evalNamespace make_exports("contents", with_map = TRUE)
+#' @evalNamespace make_namespace_S3_entries("contents")
+#' @aliases contents contents<- map_contents
+#' @name set_contents
+#' @examples
+#'
+#' set_contents(jams, 2, 1, "Blackcurrant")
+#' map_contents(jams, by_regex(".*berry" = "Snodberry"))
+NULL
+make_getter_setters("contents", "cell")
+
+#' @evalNamespace "S3method(contents, huxtable)"
+contents.huxtable <- function (ht) ht
+
+
+#' @evalNamespace "S3method(\"contents<-\", huxtable)"
+`contents<-.huxtable` <- function (ht, value) {
+  value # by the time we get here, the replacement has already happened and we're done
+}
+
+#' @aliases pad_decimal<- set_pad_decimal map_pad_decimal
 #' @rdname huxtable-deprecated
 #' @name pad_decimal
 #' @details
 #' To replace `pad_decimal` use [align()], e.g. `align(ht) <- "."`.
-#' @export pad_decimal pad_decimal<- set_pad_decimal
 NULL
-make_getter_setters('pad_decimal', 'cell', extra_code = {
+make_getter_setters("pad_decimal", "cell", extra_code = {
   stopifnot(all(nchar(na.omit(value)) == 1))
-  .Deprecated(msg = "'pad_decimal' is deprecated.\nUse e.g. 'align(x) <- \".\"' instead.")
+  .Deprecated(msg = "`pad_decimal` is deprecated.\nUse e.g. `align(x) <- \".\"`` instead.",
+        package = "huxtable")
 })
 
 
@@ -766,47 +803,48 @@ make_getter_setters('pad_decimal', 'cell', extra_code = {
 #' @templateVar value_param_desc
 #' A character vector of font names. NB that LaTeX and HTML use different font names.
 #' @template getset-example
-#' @templateVar attr_val 'times'
+#' @templateVar attr_val "times"
 #' @template getset-rowspec-example
-#' @templateVar attr_val2 'arial'
+#' @templateVar attr_val2 "arial"
 #' @family formatting functions
-#' @export font font<- set_font
+#' @template cell-property-usage
 NULL
-make_getter_setters('font', 'cell', check_fun = is.character)
+make_getter_setters("font", "cell", check_fun = is.character)
 
 
 #' @template getset-table
 #' @templateVar attr_name position
 #' @templateVar attr_desc Table position
 #' @templateVar value_param_desc
-#' A length-one character vector which may be 'left', 'center' or 'right'.
+#' A length-one character vector which may be "left", "center" or "right".
 #' @details
 #' If your tables are too far to the right under LaTeX, try setting their [width()]
 #' explicitly.
 #' @template getset-example
-#' @templateVar attr_val 'right'
-#' @export position position<- set_position
+#' @templateVar attr_val "right"
 NULL
-make_getter_setters('position', 'table', check_values = c('left', 'center', 'centre', 'right'),
-      extra_code = value[value == 'centre'] <- 'center')
+make_getter_setters("position", "table", check_values = c("left", "center", "centre", "right"),
+      extra_code = value[value == "centre"] <- "center")
 
 #' @template getset-table
 #' @templateVar attr_name caption_pos
 #' @templateVar attr_desc Caption position
 #' @templateVar value_param_desc
-#' A length-one character vector, one of 'top', 'bottom', 'topleft', 'topcenter', 'topright', 'bottomleft', 'bottomcenter', 'bottomright'.
+#' A length-one character vector, one of "top", "bottom", "topleft", "topcenter", "topright", "bottomleft", "bottomcenter", "bottomright".
 #' @details
-#' If `caption_pos` is 'top' or 'bottom', then the horizontal position ('left', 'center' or 'right')
-#' will be determined by the huxtable's [position()].
-#' @template getset-example
-#' @templateVar attr_val 'bottom'
+#' If `caption_pos` is "top" or "bottom", then the horizontal position ("left", "center" or "right")
+#' will be determined by the huxtable"s [position()].
 #' @seealso [caption()]
-#' @export caption_pos caption_pos<- set_caption_pos
+#' @examples
+#' caption(jams) <- "Price list"
+#' jams
+#' caption_pos(jams) <- "top"
+#' jams
 NULL
-make_getter_setters('caption_pos', 'table', check_values = c('top', 'bottom', 'topleft', 'topcenter', 'topcentre',
-      'topright', 'bottomleft', 'bottomcenter', 'bottomcentre', 'bottomright'), extra_code = {
-        value[value == 'topcentre'] <- 'topcenter'
-        value[value == 'bottomcentre'] <- 'bottomcenter'
+make_getter_setters("caption_pos", "table", check_values = c("top", "bottom", "topleft", "topcenter", "topcentre",
+      "topright", "bottomleft", "bottomcenter", "bottomcentre", "bottomright"), extra_code = {
+        value[value == "topcentre"] <- "topcenter"
+        value[value == "bottomcentre"] <- "bottomcenter"
       })
 
 
@@ -818,9 +856,8 @@ make_getter_setters('caption_pos', 'table', check_values = c('top', 'bottom', 't
 #' @template getset-example
 #' @templateVar attr_val 0.8
 #' @family table measurements
-#' @export width width<- set_width
 NULL
-make_getter_setters('width', 'table')
+make_getter_setters("width", "table")
 
 
 #' @template getset-table
@@ -831,9 +868,8 @@ make_getter_setters('width', 'table')
 #' @template getset-example
 #' @templateVar attr_val 0.4
 #' @family table measurements
-#' @export height height<- set_height
 NULL
-make_getter_setters('height', 'table')
+make_getter_setters("height", "table")
 
 #' @template getset-table
 #' @templateVar attr_name caption
@@ -843,15 +879,17 @@ make_getter_setters('height', 'table')
 #' @details
 #' Captions are not escaped. See the example for a workaround.
 #' @template getset-example
-#' @templateVar attr_val 'An example table'
-#' @templateVar extra print_screen(ht)
+#' @templateVar attr_val "An example table"
+#' @templateVar extra jams
 #' @seealso [caption_pos()]
 #' @examples
-#' ht <- hux(a = 1:2, b = 1:2)
-#' caption(ht) <- sanitize('Make $$$ with us', type = 'latex') # escape caption characters
-#' @export caption caption<- set_caption
+#'
+#' # escape caption characters:
+#' caption(jams) <- sanitize(
+#'       "Make $$$ with jam",
+#'       type = "latex")
 NULL
-make_getter_setters('caption', 'table', check_fun = is.character)
+make_getter_setters("caption", "table", check_fun = is.character)
 
 
 #' @template getset-table
@@ -860,14 +898,10 @@ make_getter_setters('caption', 'table', check_fun = is.character)
 #' @templateVar value_param_desc
 #' A length-one character vector.
 #' @template getset-example
-#' @templateVar attr_val 'longtable'
+#' @templateVar attr_val "longtable"
 #' @details No features are guaranteed to work if you set this to a non-default value. Use at your own risk!
-#' @export tabular_environment tabular_environment<- set_tabular_environment
 NULL
-make_getter_setters('tabular_environment', 'table', check_fun = is.character)
-
-
-
+make_getter_setters("tabular_environment", "table", check_fun = is.character)
 
 
 #' @template getset-table
@@ -876,13 +910,16 @@ make_getter_setters('tabular_environment', 'table', check_fun = is.character)
 #' @templateVar value_param_desc
 #' A length-one character vector to be used as a table label in LaTeX, or as an ID for the table in HTML.
 #' @template getset-example
-#' @templateVar attr_val 'tab:mytable'
+#' @templateVar attr_val "tab:mytable"
 #' @details
-#' LaTeX table labels typically start with "tab:", and they must do so if you want table numbering
-#' in \href{http://bookdown.org}{bookdown}.
-#' @export label label<- set_label
+#' LaTeX table labels typically start with `"tab:"`.
+#'
+#' If you use \href{http://bookdown.org}{bookdown}, and set a label on your table,
+#' the caption will automatically be prefixed with `(#label)`. You can then
+#' refer to the table using `@ref(label)`. `label` needs to start with `"tab:"`; if it doesn't,
+#' the `"tab"` prefix will be added automatically.
 NULL
-make_getter_setters('label', 'table', check_fun = is.character)
+make_getter_setters("label", "table", check_fun = is.character)
 
 
 #' @template getset-table
@@ -891,10 +928,9 @@ make_getter_setters('label', 'table', check_fun = is.character)
 #' @templateVar value_param_desc
 #' A length-one character vector, used by LaTeX for positioning the float.
 #' @template getset-example
-#' @templateVar attr_val 'h'
-#' @details Quick reference: 'h' here, 'h!' definitely here, 't' top of page, 'b' bottom of page, 'p' page of
-#' floats. See LaTeX documentation for more details. If you use 'H' (definitely here), you must require the
+#' @templateVar attr_val "h"
+#' @details Quick reference: "h" here, "h!" definitely here, "t" top of page, "b" bottom of page, "p" page of
+#' floats. See LaTeX documentation for more details. If you use "H" (definitely here), you must require the
 #' TeX `float` package.
-#' @export latex_float latex_float<- set_latex_float
 NULL
-make_getter_setters('latex_float', 'table', check_fun = is.character)
+make_getter_setters("latex_float", "table", check_fun = is.character)
